@@ -41,6 +41,8 @@ type GoldenFileOptions = struct {
 	// RunTerraformCLI sets the cmd test to also run the cmd with --terraform-force-cli set
 	RunTerraformCLI bool
 	IgnoreNonGraph  bool
+	IgnoreLogs      bool
+	LogLevel        *string
 }
 
 func DefaultOptions() *GoldenFileOptions {
@@ -128,10 +130,13 @@ func GetCommandOutput(t *testing.T, args []string, testOptions *GoldenFileOption
 		c.OutWriter = outBuf
 		c.Exit = func(code int) {}
 
-		if testOptions.CaptureLogs {
-			logBuf = testutil.ConfigureTestToCaptureLogs(t, c)
-		} else {
-			testutil.ConfigureTestToFailOnLogs(t, c)
+		level := "warn"
+		if testOptions.LogLevel != nil {
+			level = *testOptions.LogLevel
+		}
+
+		if !testOptions.IgnoreLogs {
+			logBuf = testutil.ConfigureTestToCaptureLogs(t, c, level)
 		}
 
 		for _, option := range ctxOptions {
