@@ -21,3 +21,9 @@ func TestCommentGitLabCommit(t *testing.T) {
 		[]string{"comment", "gitlab", "--gitlab-token", "abc", "--repo", "test/test", "--commit", "5", "--path", "./testdata/terraform_v0.14_breakdown.json", "--dry-run"},
 		nil)
 }
+
+func TestCommentGitLabCommentPath(t *testing.T) {
+	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(),
+		[]string{"comment", "gitlab", "--gitlab-token", "abc", "--repo", "test/test", "--merge-request", "5", "--path", "./testdata/terraform_v0.14_breakdown.json", "--comment-path", "./testdata/comment.md", "--dry-run"},
+		nil)
+}
