@@ -146,7 +146,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 				if ctx.Config.IsSelfHosted() {
 					logging.Logger.Warn().Msg("Infracost Cloud is part of Infracost's hosted services. Contact hello@infracost.io for help.")
 				} else {
-					result := shareCombinedRun(ctx, combined, inputs, apiclient.CommentFormatMarkdownHTML)
+					result := shareCombinedRun(ctx, combined, inputs)
 					combined.RunID, combined.ShareURL, combined.CloudURL = result.RunID, result.ShareURL, result.CloudURL
 				}
 			}
@@ -193,7 +193,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 	return cmd
 }
 
-func shareCombinedRun(ctx *config.RunContext, combined output.Root, inputs []output.ReportInput, commentFormat apiclient.CommentFormat) apiclient.AddRunResponse {
+func shareCombinedRun(ctx *config.RunContext, combined output.Root, inputs []output.ReportInput) apiclient.AddRunResponse {
 	combinedRunIds := []string{}
 	for _, input := range inputs {
 		if id := input.Root.RunID; id != "" {
@@ -203,7 +203,7 @@ func shareCombinedRun(ctx *config.RunContext, combined output.Root, inputs []out
 	ctx.ContextValues.SetValue("runIds", combinedRunIds)
 
 	dashboardClient := apiclient.NewDashboardAPIClient(ctx)
-	result, err := dashboardClient.AddRun(ctx, combined, commentFormat)
+	result, err := dashboardClient.AddRun(ctx, combined)
 	if err != nil {
 		logging.Logger.Err(err).Msg("Failed to upload to Infracost Cloud")
 	}
