@@ -72,7 +72,7 @@ func TestUploadWithPathFormatJSON(t *testing.T) {
 		  "cloudUrl": "https://dashboard.infracost.io/org/tim/repos/4e936c53-6091-4836-82da-e106ff653aec/runs/ff050cb8-eaaa-479f-8865-3fc0fd689b9f",
 		  "pullRequestUrl": "https://dashboard.infracost.io/org/tim/repos/4e936c53-6091-4836-82da-e106ff653aec/pulls/null",
 		  "governanceFailures": null,
-		  "governanceComment": "\n<h4>Governance checks</h4>\n\n<details>\n<summary><strong>🔴 4 failures</strong>...",
+		  "commentMarkdown": "\n<h4>Governance checks</h4>\n\n<details>\n<summary><strong>🔴 4 failures</strong>...",
 		  "governanceResults": [
 			{
 			  "govType": "tag_policy",
@@ -160,7 +160,7 @@ func TestUploadWithCloudDisabled(t *testing.T) {
 
 func TestUploadWithGuardrailSuccess(t *testing.T) {
 	ts := governanceTestEndpoint(governanceAddRunResponse{
-		GovernanceComment: "",
+		CommentMarkdown: "",
 		GovernanceResults: []GovernanceResult{{
 			Type:    "guardrail",
 			Checked: 2,
@@ -182,7 +182,7 @@ func TestUploadWithGuardrailSuccess(t *testing.T) {
 
 func TestUploadWithGuardrailFailure(t *testing.T) {
 	ts := governanceTestEndpoint(governanceAddRunResponse{
-		GovernanceComment: "",
+		CommentMarkdown: "",
 		GovernanceResults: []GovernanceResult{{
 			Type:    "guardrail",
 			Checked: 2,
@@ -208,7 +208,7 @@ func TestUploadWithGuardrailFailure(t *testing.T) {
 
 func TestUploadWithBlockingGuardrailFailure(t *testing.T) {
 	ts := governanceTestEndpoint(governanceAddRunResponse{
-		GovernanceComment: "",
+		CommentMarkdown: "",
 		GovernanceResults: []GovernanceResult{{
 			Type:    "guardrail",
 			Checked: 2,
@@ -242,7 +242,7 @@ func TestUploadWithBlockingTagPolicyFailure(t *testing.T) {
 	defer policyV2Api.Close()
 
 	dashboardApi := governanceTestEndpoint(governanceAddRunResponse{
-		GovernanceComment: "Tag policy failure",
+		CommentMarkdown: "Tag policy failure",
 		GovernanceResults: []GovernanceResult{{
 			Type:    "tag_policy",
 			Checked: 2,
@@ -311,7 +311,7 @@ func TestUploadWithBlockingFinOpsPolicyFailure(t *testing.T) {
 	defer policyV2Api.Close()
 
 	dashboardApi := governanceTestEndpoint(governanceAddRunResponse{
-		GovernanceComment: "FinOPs policy failure",
+		CommentMarkdown: "FinOPs policy failure",
 		GovernanceResults: []GovernanceResult{{
 			Type:    "finops_policy",
 			Checked: 2,
