@@ -4,29 +4,29 @@ import (
 	"fmt"
 	"strings"
 
-	log "github.com/sirupsen/logrus"
+	"github.com/rs/zerolog"
 )
 
 // LeveledLogger is a wrapper around logrus.Entry that implements the
 // retryablehttp.LeveledLogger interface.
 type LeveledLogger struct {
-	Logger *log.Entry
+	Logger zerolog.Logger
 }
 
 func (l *LeveledLogger) Error(msg string, keysAndValues ...interface{}) {
-	l.Logger.Error(joinMessage(msg, keysAndValues))
+	l.Logger.Error().Msg(joinMessage(msg, keysAndValues))
 }
 
 func (l *LeveledLogger) Info(msg string, keysAndValues ...interface{}) {
-	l.Logger.Info(joinMessage(msg, keysAndValues))
+	l.Logger.Info().Msg(joinMessage(msg, keysAndValues))
 }
 
 func (l *LeveledLogger) Debug(msg string, keysAndValues ...interface{}) {
-	l.Logger.Debug(joinMessage(msg, keysAndValues))
+	l.Logger.Debug().Msg(joinMessage(msg, keysAndValues))
 }
 
 func (l *LeveledLogger) Warn(msg string, keysAndValues ...interface{}) {
-	l.Logger.Warn(joinMessage(msg, keysAndValues))
+	l.Logger.Warn().Msg(joinMessage(msg, keysAndValues))
 }
 
 func joinMessage(msg string, keysAndValues []interface{}) string {
