@@ -6,8 +6,9 @@ import (
 	"strings"
 
 	"github.com/pkg/errors"
-	"github.com/rs/zerolog/log"
 	"gopkg.in/yaml.v2"
+
+	"github.com/infracost/infracost/internal/logging"
 )
 
 var credentialsVersion = "0.1"
@@ -23,7 +24,7 @@ func loadCredentials(cfg *Config) error {
 
 	err = cfg.migrateCredentials()
 	if err != nil {
-		log.Debug().Err(err).Msg("Error migrating credentials")
+		logging.Logger.Debug().Err(err).Msg("Error migrating credentials")
 	}
 
 	cfg.Credentials, err = readCredentialsFileIfExists()
