@@ -19,6 +19,7 @@ import (
 	"github.com/zclconf/go-cty/cty/gocty"
 
 	"github.com/infracost/infracost/internal/config"
+	"github.com/infracost/infracost/internal/hcl/modules"
 )
 
 var (
@@ -959,6 +960,7 @@ type RootPath struct {
 
 	HasChildVarFiles bool
 	IsTerragrunt     bool
+	ModuleCalls      []string
 }
 
 func (r *RootPath) RelPath() string {
@@ -1158,6 +1160,7 @@ func (p *ProjectLocator) FindRootModules(startingPath string) []RootPath {
 				StartingPath:      startingPath,
 				DetectedPath:      dir.path,
 				HasChanges:        p.hasChanges(dir.path),
+				ModuleCalls:       p.moduleCalls[dir.path],
 				TerraformVarFiles: p.discoveredVarFiles[dir.path],
 				Matcher:           p.envMatcher,
 				IsTerragrunt:      dir.isTerragrunt,
@@ -1173,6 +1176,7 @@ func (p *ProjectLocator) FindRootModules(startingPath string) []RootPath {
 					StartingPath:      startingPath,
 					DetectedPath:      dir.path,
 					HasChanges:        p.hasChanges(dir.path),
+					ModuleCalls:       p.moduleCalls[dir.path],
 					TerraformVarFiles: p.discoveredVarFiles[dir.path],
 					Matcher:           p.envMatcher,
 					IsTerragrunt:      dir.isTerragrunt,
@@ -1459,11 +1463,13 @@ func (p *ProjectLocator) walkPaths(fullPath string, level int, maxSearchDepth in
 
 	for _, info := range fileInfos {
 		if info.IsDir() {
-			if strings.HasPrefix(info.Name(), ".") {
+			fullPath := filepath.Join(fullPath, info.Name())
+
+			if strings.HasPrefix(info.Name(), ".") && !p.shouldIncludeDir(fullPath) {
 				continue
 			}
 
-			p.walkPaths(filepath.Join(fullPath, info.Name()), level+1, maxSearchDepth)
+			p.walkPaths(fullPath, level+1, maxSearchDepth)
 		}
 	}
 }
@@ -1623,6 +1629,12 @@ func (p *ProjectLocator) shallowDecodeTerraformBlocks(fullPath string, files map
 					continue
 				}
 
+				// we only care about local modules for building a dependency tree
+				// so skip any remote modules here.
+				if !modules.IsLocalModule(realPath) {
+					continue
+				}
+
 				mp := filepath.Join(fullPath, realPath)
 				p.modules[mp] = struct{}{}
 				if v, ok := p.moduleCalls[fullPath]; ok {
