@@ -7,18 +7,16 @@ import (
 
 func getCodeBuildProjectRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_codebuild_project",
-		RFunc: NewCodeBuildProject,
+		Name:      "aws_codebuild_project",
+		CoreRFunc: NewCodeBuildProject,
 	}
 }
-func NewCodeBuildProject(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewCodeBuildProject(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.CodeBuildProject{
 		Address:         d.Address,
 		Region:          d.Get("region").String(),
 		ComputeType:     d.Get("environment.0.compute_type").String(),
 		EnvironmentType: d.Get("environment.0.type").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
