@@ -7,19 +7,17 @@ import (
 
 func getDXConnectionRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_dx_connection",
-		RFunc: NewDXConnection,
+		Name:      "aws_dx_connection",
+		CoreRFunc: NewDXConnection,
 	}
 }
 
-func NewDXConnection(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewDXConnection(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.DXConnection{
 		Address:   d.Address,
 		Region:    d.Get("region").String(),
 		Bandwidth: d.Get("bandwidth").String(),
 		Location:  d.Get("location").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
