@@ -7,16 +7,14 @@ import (
 
 func getEC2TrafficMirrorSessionRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_ec2_traffic_mirror_session",
-		RFunc: NewEC2TrafficMirrorSession,
+		Name:      "aws_ec2_traffic_mirror_session",
+		CoreRFunc: NewEC2TrafficMirrorSession,
 	}
 }
-func NewEC2TrafficMirrorSession(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewEC2TrafficMirrorSession(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.EC2TrafficMirrorSession{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
