@@ -47,6 +47,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getECSClusterRegistryItem(),
 	getECSServiceRegistryItem(),
 	getECSTaskDefinitionRegistryItem(),
+	getECSTaskSet(),
 	getEFSFileSystemRegistryItem(),
 	getEIPRegistryItem(),
 	getEIPAssociationRegistryItem(),
@@ -84,7 +85,6 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getRoute53ZoneRegistryItem(),
 	getS3BucketAnalyticsConfigurationRegistryItem(),
 	getS3BucketInventoryRegistryItem(),
-	getS3BucketLifecycleConfigurationRegistryItem(),
 	getS3BucketRegistryItem(),
 	getSecretsManagerSecret(),
 	getSSMActivationRegistryItem(),
