@@ -7,16 +7,14 @@ import (
 
 func getRoute53ZoneRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_route53_zone",
-		RFunc: NewRoute53Zone,
+		Name:      "aws_route53_zone",
+		CoreRFunc: NewRoute53Zone,
 	}
 }
 
-func NewRoute53Zone(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewRoute53Zone(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.Route53Zone{
 		Address: d.Address,
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
