@@ -23,3 +23,14 @@ func TestS3BucketV3GoldenFile(t *testing.T) {
 
 	tftest.GoldenFileResourceTests(t, "s3_bucket_v3_test")
 }
+
+func TestS3BucketChinaGoldenFile(t *testing.T) {
+	t.Parallel()
+	if testing.Short() {
+		t.Skip("skipping test in short mode")
+	}
+
+	tftest.GoldenFileResourceTestsWithOpts(t, "s3_bucket_china_test", &tftest.GoldenFileOptions{
+		Currency: "CNY",
+	})
+}
