@@ -14,7 +14,7 @@ func getAppServicePlanRegistryItem() *schema.RegistryItem {
 func NewAppServicePlan(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.AppServicePlan{
 		Address:     d.Address,
-		Region:      lookupRegion(d, []string{}),
+		Region:      d.Region,
 		SKUSize:     d.Get("sku.0.size").String(),
 		SKUCapacity: d.Get("sku.0.capacity").Int(),
 		Kind:        d.Get("kind").String(),
