@@ -16,7 +16,7 @@ func getApplicationInsightsStandardWebTestRegistryItem() *schema.RegistryItem {
 }
 
 func newApplicationInsightsStandardWebTest(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 	return &azure.ApplicationInsightsStandardWebTest{
 		Address:   d.Address,
 		Region:    region,
