@@ -1,8 +1,6 @@
 package azure
 
 import (
-	"github.com/tidwall/gjson"
-
 	"github.com/infracost/infracost/internal/providers/terraform/provider_schemas"
 	"github.com/infracost/infracost/internal/schema"
 )
@@ -21,10 +19,6 @@ func GetSpecialContext(d *schema.ResourceData) map[string]interface{} {
 	return map[string]interface{}{}
 }
 
-func GetResourceRegion(resourceType string, v gjson.Result) string {
-	return ""
-}
-
 func ParseTags(r *schema.ResourceData) *map[string]string {
 	_, supportsTags := provider_schemas.AzureTagsSupport[r.Type]
 	rTags := r.Get("tags").Map()
