@@ -19,7 +19,7 @@ func getCognitiveAccountRegistryItem() *schema.RegistryItem {
 }
 
 func newCognitiveAccount(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 	kind := d.Get("kind").String()
 
 	if strings.EqualFold(kind, "speechservices") {
