@@ -1,8 +1,7 @@
 package azure
 
 import (
-	"github.com/rs/zerolog/log"
-
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/schema"
 )
 
@@ -27,9 +26,9 @@ func NewAzureRMCosmosdbCassandraTable(d *schema.ResourceData, u *schema.UsageDat
 				CostComponents: cosmosDBCostComponents(d, u, account),
 			}
 		}
-		log.Warn().Msgf("Skipping resource %s as its 'cassandra_keyspace_id.account_name' property could not be found.", d.Address)
+		logging.Logger.Warn().Msgf("Skipping resource %s as its 'cassandra_keyspace_id.account_name' property could not be found.", d.Address)
 		return nil
 	}
-	log.Warn().Msgf("Skipping resource %s as its 'cassandra_keyspace_id' property could not be found.", d.Address)
+	logging.Logger.Warn().Msgf("Skipping resource %s as its 'cassandra_keyspace_id' property could not be found.", d.Address)
 	return nil
 }
