@@ -19,25 +19,25 @@ func getDataFactoryIntegrationRuntimeManagedRegistryItem() *schema.RegistryItem
 			"data_factory_name",
 			"resource_group_name",
 		},
+		GetRegion: func(defaultRegion string, d *schema.ResourceData) string {
+			region := lookupRegion(d, []string{"resource_group_name", "data_factory_id", "data_factory_name"})
+
+			dataFactoryIdRefs := d.References("data_factory_id")
+			if region == "" && len(dataFactoryIdRefs) > 0 {
+				region = lookupRegion(dataFactoryIdRefs[0], []string{"resource_group_name"})
+			}
+
+			// Old provider versions < 3 can reference data_factory_name
+			dataFactoryNameRefs := d.References("data_factory_name")
+			if region == "" && len(dataFactoryNameRefs) > 0 {
+				region = lookupRegion(dataFactoryNameRefs[0], []string{"resource_group_name"})
+			}
+			return region
+		},
 	}
 }
 
 func newDataFactoryIntegrationRuntimeManaged(d *schema.ResourceData) schema.CoreResource {
-	var region string
-
-	region = lookupRegion(d, []string{"resource_group_name", "data_factory_id", "data_factory_name"})
-
-	dataFactoryIdRefs := d.References("data_factory_id")
-	if region == "" && len(dataFactoryIdRefs) > 0 {
-		region = lookupRegion(dataFactoryIdRefs[0], []string{"resource_group_name"})
-	}
-
-	// Old provider versions < 3 can reference data_factory_name
-	dataFactoryNameRefs := d.References("data_factory_name")
-	if region == "" && len(dataFactoryNameRefs) > 0 {
-		region = lookupRegion(dataFactoryNameRefs[0], []string{"resource_group_name"})
-	}
-
 	licenseType := d.GetStringOrDefault("license_type", "LicenseIncluded")
 	licenseIncluded := strings.EqualFold(licenseType, "LicenseIncluded")
 
@@ -52,7 +52,7 @@ func newDataFactoryIntegrationRuntimeManaged(d *schema.ResourceData) schema.Core
 
 	r := &azure.DataFactoryIntegrationRuntimeManaged{
 		Address:         d.Address,
-		Region:          region,
+		Region:          d.Region,
 		Enterprise:      enterprise,
 		LicenseIncluded: licenseIncluded,
 		Instances:       nodes,
