@@ -16,11 +16,14 @@ func GetAzureRMLoadBalancerRuleRegistryItem() *schema.RegistryItem {
 		ReferenceAttributes: []string{
 			"loadbalancer_id",
 		},
+		GetRegion: func(defaultRegion string, d *schema.ResourceData) string {
+			return lookupRegion(d, []string{"loadbalancer_id"})
+		},
 	}
 }
 
 func NewAzureRMLoadBalancerRule(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	region := lookupRegion(d, []string{"loadbalancer_id"})
+	region := d.Region
 	region = convertRegion(region)
 
 	lbSku := getParentLbSku(d.References("loadbalancer_id"))
