@@ -18,7 +18,7 @@ func GetAzureRMMariaDBServerRegistryItem() *schema.RegistryItem {
 }
 
 func NewAzureRMMariaDBServer(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	region := lookupRegion(d, []string{})
+	region := d.Region
 
 	var costComponents []*schema.CostComponent
 	serviceName := "Azure Database for MariaDB"
