@@ -16,7 +16,7 @@ func getServiceBusNamespaceRegistryItem() *schema.RegistryItem {
 }
 
 func newServiceBusNamespace(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 	return &azure.ServiceBusNamespace{
 		Address:  d.Address,
 		Region:   region,
