@@ -16,7 +16,7 @@ func getSQLManagedInstanceRegistryItem() *schema.RegistryItem {
 }
 
 func newSQLManagedInstance(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 	r := &azure.SQLManagedInstance{
 		Address: d.Address,
 		Region:  region,
