@@ -18,10 +18,9 @@ import (
 	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/credentials"
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/ui"
-
-	"github.com/rs/zerolog/log"
 )
 
 var minTerraformVer = "v0.12"
@@ -29,7 +28,6 @@ var minTerraformVer = "v0.12"
 type DirProvider struct {
 	ctx                  *config.ProjectContext
 	Path                 string
-	spinnerOpts          ui.SpinnerOptions
 	IsTerragrunt         bool
 	PlanFlags            string
 	InitFlags            string
@@ -55,13 +53,8 @@ func NewDirProvider(ctx *config.ProjectContext, includePastResources bool) schem
 	}
 
 	return &DirProvider{
-		ctx:  ctx,
-		Path: ctx.ProjectConfig.Path,
-		spinnerOpts: ui.SpinnerOptions{
-			EnableLogging: ctx.RunContext.Config.IsLogging(),
-			NoColor:       ctx.RunContext.Config.NoColor,
-			Indent:        "  ",
-		},
+		ctx:                  ctx,
+		Path:                 ctx.ProjectConfig.Path,
 		PlanFlags:            ctx.ProjectConfig.TerraformPlanFlags,
 		InitFlags:            ctx.ProjectConfig.TerraformInitFlags,
 		Workspace:            ctx.ProjectConfig.TerraformWorkspace,
@@ -74,6 +67,28 @@ func NewDirProvider(ctx *config.ProjectContext, includePastResources bool) schem
 	}
 }
 
+func (p *DirProvider) ProjectName() string {
+	if p.ctx.ProjectConfig.Name != "" {
+		return p.ctx.ProjectConfig.Name
+	}
+
+	if p.ctx.ProjectConfig.TerraformWorkspace != "" {
+		return config.CleanProjectName(p.RelativePath()) + "-" + p.ctx.ProjectConfig.TerraformWorkspace
+	}
+
+	return config.CleanProjectName(p.RelativePath())
+}
+
+func (p *DirProvider) VarFiles() []string {
+	return nil
+}
+
+func (p *DirProvider) RelativePath() string {
+	r, _ := filepath.Rel(p.ctx.RunContext.Config.WorkingDirectory(), p.ctx.ProjectConfig.Path)
+
+	return r
+}
+
 func (p *DirProvider) Context() *config.ProjectContext { return p.ctx }
 
 func (p *DirProvider) Type() string {
@@ -115,14 +130,8 @@ func (p *DirProvider) checks() error {
 func (p *DirProvider) AddMetadata(metadata *schema.ProjectMetadata) {
 	metadata.ConfigSha = p.ctx.ProjectConfig.ConfigSha
 
-	basePath := p.ctx.ProjectConfig.Path
-	if p.ctx.RunContext.Config.ConfigFilePath != "" {
-		basePath = filepath.Dir(p.ctx.RunContext.Config.ConfigFilePath)
-	}
-
-	modulePath, err := filepath.Rel(basePath, metadata.Path)
-	if err == nil && modulePath != "" && modulePath != "." {
-		log.Debug().Msgf("Calculated relative terraformModulePath for %s from %s", basePath, metadata.Path)
+	modulePath := p.RelativePath()
+	if modulePath != "" && modulePath != "." {
 		metadata.TerraformModulePath = modulePath
 	}
 
@@ -135,7 +144,7 @@ func (p *DirProvider) AddMetadata(metadata *schema.ProjectMetadata) {
 
 		out, err := cmd.Output()
 		if err != nil {
-			log.Debug().Msgf("Could not detect Terraform workspace for %s", p.Path)
+			logging.Logger.Debug().Msgf("Could not detect Terraform workspace for %s", p.Path)
 		}
 		terraformWorkspace = strings.Split(string(out), "\n")[0]
 	}
@@ -157,12 +166,7 @@ func (p *DirProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, e
 		return projects, err
 	}
 
-	spinner := ui.NewSpinner("Extracting only cost-related params from terraform", ui.SpinnerOptions{
-		EnableLogging: p.ctx.RunContext.Config.IsLogging(),
-		NoColor:       p.ctx.RunContext.Config.NoColor,
-		Indent:        "  ",
-	})
-	defer spinner.Fail()
+	logging.Logger.Debug().Msg("Extracting only cost-related params from terraform")
 
 	jsons := [][]byte{out}
 	if p.IsTerragrunt {
@@ -182,6 +186,7 @@ func (p *DirProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, e
 		}
 
 		project := schema.NewProject(name, metadata)
+		project.DisplayName = p.ProjectName()
 
 		parser := NewParser(p.ctx, p.includePastResources)
 
@@ -202,7 +207,6 @@ func (p *DirProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, e
 		projects = append(projects, project)
 	}
 
-	spinner.Success()
 	return projects, nil
 }
 
@@ -212,15 +216,14 @@ func (p *DirProvider) generatePlanJSON() ([]byte, error) {
 	}
 
 	if UsePlanCache(p) {
-		spinner := ui.NewSpinner("Checking for cached plan...", p.spinnerOpts)
-		defer spinner.Fail()
+		logging.Logger.Debug().Msg("Checking for cached plan...")
 
 		cached, err := ReadPlanCache(p)
 		if err != nil {
-			spinner.SuccessWithMessage(fmt.Sprintf("Checking for cached plan... %v", err.Error()))
+			logging.Logger.Debug().Msgf("Checking for cached plan... %v", err.Error())
 		} else {
 			p.cachedPlanJSON = cached
-			spinner.SuccessWithMessage("Checking for cached plan... found")
+			logging.Logger.Debug().Msg("Checking for cached plan... found")
 			return p.cachedPlanJSON, nil
 		}
 	}
@@ -238,10 +241,7 @@ func (p *DirProvider) generatePlanJSON() ([]byte, error) {
 		defer os.Remove(opts.TerraformConfigFile)
 	}
 
-	spinner := ui.NewSpinner("Running terraform plan", p.spinnerOpts)
-	defer spinner.Fail()
-
-	planFile, planJSON, err := p.runPlan(opts, spinner, true)
+	planFile, planJSON, err := p.runPlan(opts, true)
 	defer os.Remove(planFile)
 
 	if err != nil {
@@ -252,8 +252,7 @@ func (p *DirProvider) generatePlanJSON() ([]byte, error) {
 		return planJSON, nil
 	}
 
-	spinner = ui.NewSpinner("Running terraform show", p.spinnerOpts)
-	j, err := p.runShow(opts, spinner, planFile, false)
+	j, err := p.runShow(opts, planFile, false)
 	if err == nil {
 		p.cachedPlanJSON = j
 		if UsePlanCache(p) {
@@ -282,10 +281,7 @@ func (p *DirProvider) generateStateJSON() ([]byte, error) {
 		defer os.Remove(opts.TerraformConfigFile)
 	}
 
-	spinner := ui.NewSpinner("Running terraform show", p.spinnerOpts)
-	defer spinner.Fail()
-
-	j, err := p.runShow(opts, spinner, "", true)
+	j, err := p.runShow(opts, "", true)
 	if err == nil {
 		p.cachedStateJSON = j
 	}
@@ -310,7 +306,8 @@ func (p *DirProvider) buildCommandOpts(path string) (*CmdOptions, error) {
 	return opts, nil
 }
 
-func (p *DirProvider) runPlan(opts *CmdOptions, spinner *ui.Spinner, initOnFail bool) (string, []byte, error) {
+func (p *DirProvider) runPlan(opts *CmdOptions, initOnFail bool) (string, []byte, error) {
+	logging.Logger.Debug().Msg("Running terraform plan")
 	var planJSON []byte
 
 	fileName := ".tfplan-" + uuid.New().String()
@@ -339,21 +336,20 @@ func (p *DirProvider) runPlan(opts *CmdOptions, spinner *ui.Spinner, initOnFail
 
 		// If the plan returns this error then Terraform is configured with remote execution mode
 		if isTerraformRemoteExecutionErr(extractedErr) {
-			log.Info().Msg("Continuing with Terraform Remote Execution Mode")
+			logging.Logger.Debug().Msg("Continuing with Terraform Remote Execution Mode")
 			p.ctx.ContextValues.SetValue("terraformRemoteExecutionModeEnabled", true)
 			planJSON, err = p.runRemotePlan(opts, args)
 		} else if initOnFail && isTerraformInitErr(extractedErr) {
-			spinner.Stop()
-			err = p.runInit(opts, ui.NewSpinner("Running terraform init", p.spinnerOpts))
+			err = p.runInit(opts)
 			if err != nil {
 				return "", planJSON, err
 			}
-			return p.runPlan(opts, spinner, false)
+			return p.runPlan(opts, false)
 		}
 	}
 
 	if err != nil {
-		spinner.Fail()
+		logging.Logger.Debug().Err(err).Msg("Failed terraform plan")
 		err = p.buildTerraformErr(err, false)
 
 		cmdName := "terraform plan"
@@ -364,12 +360,12 @@ func (p *DirProvider) runPlan(opts *CmdOptions, spinner *ui.Spinner, initOnFail
 		return "", planJSON, clierror.NewCLIError(fmt.Errorf("%s: %s", msg, err), msg)
 	}
 
-	spinner.Success()
-
 	return fileName, planJSON, nil
 }
 
-func (p *DirProvider) runInit(opts *CmdOptions, spinner *ui.Spinner) error {
+func (p *DirProvider) runInit(opts *CmdOptions) error {
+	logging.Logger.Debug().Msg("Running terraform init")
+
 	args := []string{}
 	if p.IsTerragrunt {
 		args = append(args, "run-all", "--terragrunt-ignore-external-dependencies")
@@ -390,7 +386,8 @@ func (p *DirProvider) runInit(opts *CmdOptions, spinner *ui.Spinner) error {
 
 	_, err = Cmd(opts, args...)
 	if err != nil {
-		spinner.Fail()
+		logging.Logger.Debug().Msg("Failed terraform init")
+
 		err = p.buildTerraformErr(err, true)
 
 		cmdName := "terraform init"
@@ -401,7 +398,7 @@ func (p *DirProvider) runInit(opts *CmdOptions, spinner *ui.Spinner) error {
 		return clierror.NewCLIError(fmt.Errorf("%s: %s", msg, err), msg)
 	}
 
-	spinner.Success()
+	logging.Logger.Debug().Msg("Finished running terraform init")
 	return nil
 }
 
@@ -458,7 +455,8 @@ func (p *DirProvider) runRemotePlan(opts *CmdOptions, args []string) ([]byte, er
 	return cloudAPI(host, jsonPath, token)
 }
 
-func (p *DirProvider) runShow(opts *CmdOptions, spinner *ui.Spinner, planFile string, initOnFail bool) ([]byte, error) {
+func (p *DirProvider) runShow(opts *CmdOptions, planFile string, initOnFail bool) ([]byte, error) {
+	logging.Logger.Debug().Msg("Running terraform show")
 	args := []string{"show", "-no-color", "-json"}
 	if planFile != "" {
 		args = append(args, planFile)
@@ -471,19 +469,18 @@ func (p *DirProvider) runShow(opts *CmdOptions, spinner *ui.Spinner, planFile st
 
 		// If the plan returns this error then Terraform is configured with remote execution mode
 		if isTerraformRemoteExecutionErr(extractedErr) {
-			log.Info().Msg("Terraform expected Remote Execution Mode")
+			logging.Logger.Debug().Msg("Terraform expected Remote Execution Mode")
 		} else if initOnFail && isTerraformInitErr(extractedErr) {
-			spinner.Stop()
-			err = p.runInit(opts, ui.NewSpinner("Running terraform init", p.spinnerOpts))
+			err = p.runInit(opts)
 			if err != nil {
 				return out, err
 			}
-			return p.runShow(opts, spinner, planFile, false)
+			return p.runShow(opts, planFile, false)
 		}
 	}
 
 	if err != nil {
-		spinner.Fail()
+		logging.Logger.Debug().Msg("Failed terraform show")
 		err = p.buildTerraformErr(err, false)
 
 		cmdName := "terraform show"
@@ -493,7 +490,7 @@ func (p *DirProvider) runShow(opts *CmdOptions, spinner *ui.Spinner, planFile st
 		msg := fmt.Sprintf("%s failed", cmdName)
 		return []byte{}, clierror.NewCLIError(fmt.Errorf("%s: %s", msg, err), msg)
 	}
-	spinner.Success()
+	logging.Logger.Debug().Msg("Finished running terraform show")
 
 	return out, nil
 }
