@@ -7,17 +7,16 @@ import (
 
 func getComputeRouterNATRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_compute_router_nat",
-		RFunc: NewComputeRouterNAT,
+		Name:      "google_compute_router_nat",
+		CoreRFunc: NewComputeRouterNAT,
 	}
 }
 
-func NewComputeRouterNAT(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewComputeRouterNAT(d *schema.ResourceData) schema.CoreResource {
 	r := &google.ComputeRouterNAT{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
 
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
