@@ -7,12 +7,11 @@ import (
 
 func getComputeVPNGatewayRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_compute_vpn_gateway",
-		RFunc: NewComputeVPNGateway,
+		Name:      "google_compute_vpn_gateway",
+		CoreRFunc: NewComputeVPNGateway,
 	}
 }
-func NewComputeVPNGateway(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewComputeVPNGateway(d *schema.ResourceData) schema.CoreResource {
 	r := &google.ComputeVPNGateway{Address: d.Address, Region: d.Get("region").String()}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
