@@ -7,16 +7,15 @@ import (
 
 func getDNSRecordSetRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_dns_record_set",
-		RFunc: NewDNSRecordSet,
+		Name:      "google_dns_record_set",
+		CoreRFunc: NewDNSRecordSet,
 	}
 }
 
-func NewDNSRecordSet(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewDNSRecordSet(d *schema.ResourceData) schema.CoreResource {
 	r := &google.DNSRecordSet{
 		Address: d.Address,
 	}
 
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
