@@ -206,6 +206,10 @@ func (p *HCLProvider) VarFiles() []string {
 	return p.Parser.VarFiles()
 }
 
+func (p *HCLProvider) DependencyPaths() []string {
+	return p.Parser.DependencyPaths()
+}
+
 func (p *HCLProvider) EnvName() string {
 	return p.Parser.EnvName()
 }
@@ -322,7 +326,7 @@ func (p *HCLProvider) LoadPlanJSON() HCLProject {
 		module.JSON, module.Error = p.modulesToPlanJSON(module.Module)
 
 		if os.Getenv("INFRACOST_JSON_DUMP") == "true" {
-			err := os.WriteFile(fmt.Sprintf("%s-out.json", strings.ReplaceAll(module.Module.ModulePath, "/", "-")), module.JSON, os.ModePerm)
+			err := os.WriteFile(fmt.Sprintf("%s-out.json", strings.ReplaceAll(module.Module.ModulePath, "/", "-")), module.JSON, os.ModePerm) // nolint: gosec
 			if err != nil {
 				p.logger.Debug().Err(err).Msg("failed to write to json dump")
 			}
@@ -398,6 +402,9 @@ func (p *HCLProvider) newPlanSchema() {
 
 func (p *HCLProvider) modulesToPlanJSON(rootModule *hcl.Module) ([]byte, error) {
 	p.newPlanSchema()
+	if rootModule.ProviderConstraints != nil {
+		p.schema.InfracostProviderConstraints = *rootModule.ProviderConstraints
+	}
 
 	mo := p.marshalModule(rootModule)
 	p.schema.Configuration.RootModule = mo.ModuleConfig
@@ -823,7 +830,8 @@ type PlanSchema struct {
 	// plan JSON output, but we omit adding it as the supported `resource_changes` key as this will cause plan inconsistencies.
 	// We copy this `infracost_resource_changes` key at a later date to `resource_changes` before sending to the Policy API.
 	// This means that we can evaluate the Rego ruleset on the known Terraform plan JSON structure.
-	InfracostResourceChanges []ResourceChangesJSON `json:"infracost_resource_changes"`
+	InfracostResourceChanges     []ResourceChangesJSON   `json:"infracost_resource_changes"`
+	InfracostProviderConstraints hcl.ProviderConstraints `json:"infracost_provider_constraints"`
 }
 
 type PlanModule struct {
