@@ -2,7 +2,7 @@ package provider_schemas
 
 import (
 	_ "embed"
-	"encoding/json"
+	json "github.com/json-iterator/go"
 )
 
 //go:embed aws.tags.json
@@ -20,11 +20,19 @@ var azurermTagsJSON []byte
 //go:embed google.labels.json
 var googleLabelsJSON []byte
 
+//go:embed google.user_labels.json
+var googleUserLabelsJSON []byte
+
+//go:embed google.settings_user_labels.json
+var googleSettingsUserLabelsJSON []byte
+
 var AWSTagsSupport map[string]bool
 var AWSTagsAllSupport map[string]bool
 var AWSTagBlockSupport map[string]bool
 var AzureTagsSupport map[string]bool
 var GoogleLabelsSupport map[string]bool
+var GoogleUserLabelsSupport map[string]bool
+var GoogleSettingsUserLabelsSupport map[string]bool
 
 func init() {
 	err := json.Unmarshal(awsTagsJSON, &AWSTagsSupport)
@@ -51,4 +59,14 @@ func init() {
 	if err != nil {
 		panic(err)
 	}
+
+	err = json.Unmarshal(googleUserLabelsJSON, &GoogleUserLabelsSupport)
+	if err != nil {
+		panic(err)
+	}
+
+	err = json.Unmarshal(googleSettingsUserLabelsJSON, &GoogleSettingsUserLabelsSupport)
+	if err != nil {
+		panic(err)
+	}
 }
