@@ -14,9 +14,15 @@ type ConfigConfigurationRecorder struct {
 	MonthlyCustomConfigItems *int64 `infracost_usage:"monthly_custom_config_items"`
 }
 
-var ConfigConfigurationRecorderUsageSchema = []*schema.UsageItem{
-	{Key: "monthly_config_items", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "monthly_custom_config_items", ValueType: schema.Int64, DefaultValue: 0},
+func (r *ConfigConfigurationRecorder) CoreType() string {
+	return "ConfigConfigurationRecorder"
+}
+
+func (r *ConfigConfigurationRecorder) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "monthly_config_items", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "monthly_custom_config_items", ValueType: schema.Int64, DefaultValue: 0},
+	}
 }
 
 func (r *ConfigConfigurationRecorder) PopulateUsage(u *schema.UsageData) {
@@ -50,6 +56,7 @@ func (r *ConfigConfigurationRecorder) BuildResource() *schema.Resource {
 				{Key: "usagetype", ValueRegex: regexPtr("ConfigurationItemRecorded$")},
 			},
 		},
+		UsageBased: true,
 	})
 
 	costComponents = append(costComponents, &schema.CostComponent{
@@ -66,11 +73,12 @@ func (r *ConfigConfigurationRecorder) BuildResource() *schema.Resource {
 				{Key: "usagetype", ValueRegex: regexPtr("CustomConfigItemRecorded$")},
 			},
 		},
+		UsageBased: true,
 	})
 
 	return &schema.Resource{
 		Name:           r.Address,
 		CostComponents: costComponents,
-		UsageSchema:    ConfigConfigurationRecorderUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 	}
 }
