@@ -5,8 +5,7 @@ import (
 	"strings"
 	"time"
 
-	"github.com/rs/zerolog/log"
-
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 
@@ -194,7 +193,7 @@ func (r *DBInstance) BuildResource() *schema.Resource {
 		}
 		priceFilter, err = resolver.PriceFilter()
 		if err != nil {
-			log.Warn().Msgf(err.Error())
+			logging.Logger.Warn().Msgf(err.Error())
 		}
 		purchaseOptionLabel = "reserved"
 	}
