@@ -1,10 +1,10 @@
 package aws
 
 import (
-	"github.com/rs/zerolog/log"
 	"golang.org/x/text/cases"
 	"golang.org/x/text/language"
 
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 
@@ -80,7 +80,7 @@ func (r *ElastiCacheCluster) elastiCacheCostComponent(autoscaling bool) *schema.
 		}
 		reservedFilter, err := resolver.PriceFilter()
 		if err != nil {
-			log.Warn().Msgf(err.Error())
+			logging.Logger.Warn().Msgf(err.Error())
 		} else {
 			priceFilter = reservedFilter
 		}
@@ -184,7 +184,7 @@ func (r elasticacheReservationResolver) PriceFilter() (*schema.PriceFilter, erro
 	}
 	nodeType := strings.Split(r.cacheNodeType, ".")[1] // Get node type from cache node type. cache.m3.large -> m3
 	if stringInSlice(elasticacheReservedNodeLegacyTypes, nodeType) {
-		log.Warn().Msgf("No products found is possible for legacy nodes %s if provided payment option is not supported by the region.", strings.Join(elasticacheReservedNodeLegacyTypes, ", "))
+		logging.Logger.Warn().Msgf("No products found is possible for legacy nodes %s if provided payment option is not supported by the region.", strings.Join(elasticacheReservedNodeLegacyTypes, ", "))
 	}
 	return &schema.PriceFilter{
 		PurchaseOption:     strPtr(purchaseOptionLabel),
