@@ -1,8 +1,10 @@
 package aws
 
 import (
-	"github.com/infracost/infracost/internal/schema"
 	"github.com/shopspring/decimal"
+
+	"github.com/infracost/infracost/internal/resources"
+	"github.com/infracost/infracost/internal/schema"
 )
 
 // GlobalAccelerator struct represents AWS Global Accelerator service
@@ -13,6 +15,18 @@ type GlobalAccelerator struct {
 	Address string
 }
 
+func (r *GlobalAccelerator) CoreType() string {
+	return "FSxOpenZFSFileSystem"
+}
+
+func (r *GlobalAccelerator) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{}
+}
+
+func (r *GlobalAccelerator) PopulateUsage(u *schema.UsageData) {
+	resources.PopulateArgsWithUsage(r, u)
+}
+
 func (r *GlobalAccelerator) BuildResource() *schema.Resource {
 	var costComponents []*schema.CostComponent
 	costComponent := &schema.CostComponent{
@@ -33,5 +47,6 @@ func (r *GlobalAccelerator) BuildResource() *schema.Resource {
 	return &schema.Resource{
 		Name:           r.Address,
 		CostComponents: costComponents,
+		UsageSchema:    r.UsageSchema(),
 	}
 }
