@@ -18,10 +18,16 @@ type NeptuneCluster struct {
 	BackupStorageGB       *float64 `infracost_usage:"backup_storage_gb"`
 }
 
-var NeptuneClusterUsageSchema = []*schema.UsageItem{
-	{Key: "storage_gb", ValueType: schema.Float64, DefaultValue: 0},
-	{Key: "monthly_io_requests", ValueType: schema.Int64, DefaultValue: 0},
-	{Key: "backup_storage_gb", ValueType: schema.Float64, DefaultValue: 0},
+func (r *NeptuneCluster) CoreType() string {
+	return "NeptuneCluster"
+}
+
+func (r *NeptuneCluster) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "storage_gb", ValueType: schema.Float64, DefaultValue: 0},
+		{Key: "monthly_io_requests", ValueType: schema.Int64, DefaultValue: 0},
+		{Key: "backup_storage_gb", ValueType: schema.Float64, DefaultValue: 0},
+	}
 }
 
 func (r *NeptuneCluster) PopulateUsage(u *schema.UsageData) {
@@ -41,7 +47,7 @@ func (r *NeptuneCluster) BuildResource() *schema.Resource {
 	return &schema.Resource{
 		Name:           r.Address,
 		CostComponents: costComponents,
-		UsageSchema:    NeptuneClusterUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 	}
 }
 
@@ -67,6 +73,7 @@ func (r *NeptuneCluster) storageCostComponent() *schema.CostComponent {
 		PriceFilter: &schema.PriceFilter{
 			PurchaseOption: strPtr("on_demand"),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -92,6 +99,7 @@ func (r *NeptuneCluster) ioRequestsCostComponent() *schema.CostComponent {
 		PriceFilter: &schema.PriceFilter{
 			PurchaseOption: strPtr("on_demand"),
 		},
+		UsageBased: true,
 	}
 }
 
@@ -117,5 +125,6 @@ func (r *NeptuneCluster) backupStorageCostComponent() *schema.CostComponent {
 		PriceFilter: &schema.PriceFilter{
 			PurchaseOption: strPtr("on_demand"),
 		},
+		UsageBased: true,
 	}
 }
