@@ -24,6 +24,7 @@ type CostComponent struct {
 	HourlyCost           *decimal.Decimal
 	MonthlyCost          *decimal.Decimal
 	UsageBased           bool
+	PriceNotFound        bool
 }
 
 func (c *CostComponent) CalculateCosts() {
@@ -49,6 +50,13 @@ func (c *CostComponent) SetPrice(price decimal.Decimal) {
 	c.price = price
 }
 
+// SetPriceNotFound zeros the price and marks the component as having a price not
+// found.
+func (c *CostComponent) SetPriceNotFound() {
+	c.price = decimal.Zero
+	c.PriceNotFound = true
+}
+
 func (c *CostComponent) Price() decimal.Decimal {
 	return c.price
 }
