@@ -10,9 +10,10 @@ import (
 	"strings"
 
 	"github.com/google/go-github/v41/github"
-	"github.com/rs/zerolog/log"
 	"golang.org/x/oauth2"
 	"golang.org/x/sync/errgroup"
+
+	"github.com/infracost/infracost/internal/logging"
 )
 
 func main() {
@@ -28,22 +29,22 @@ func main() {
 	}
 
 	if err != nil {
-		log.Error().Msgf("failed to create draft release %s", err)
+		logging.Logger.Error().Msgf("failed to create draft release %s", err)
 		return
 	}
 	toUpload, err := findReleaseAssets()
 	if err != nil {
-		log.Error().Msgf("failed to collect release assets %s", err)
+		logging.Logger.Error().Msgf("failed to collect release assets %s", err)
 		return
 	}
 
 	err = uploadAssets(toUpload, cli, release)
 	if err != nil {
-		log.Error().Msgf("failed to upload release assets %s", err)
+		logging.Logger.Error().Msgf("failed to upload release assets %s", err)
 		return
 	}
 
-	log.Info().Msg("successfully created draft release")
+	logging.Logger.Info().Msg("successfully created draft release")
 }
 
 func fetchExistingRelease(cli *github.Client, tag string) (*github.RepositoryRelease, error) {
@@ -70,7 +71,7 @@ func fetchExistingRelease(cli *github.Client, tag string) (*github.RepositoryRel
 	for _, asset := range release.Assets {
 		_, err = cli.Repositories.DeleteReleaseAsset(context.Background(), "infracost", "infracost", asset.GetID())
 		if err != nil {
-			log.Error().Msgf("failed to delete asset %s", err)
+			logging.Logger.Error().Msgf("failed to delete asset %s", err)
 			continue
 		}
 	}
@@ -165,7 +166,7 @@ func uploadAssets(toUpload []string, cli *github.Client, release *github.Reposit
 }
 
 func uploadAsset(file string, cli *github.Client, id int64) error {
-	log.Info().Msgf("uploading asset %s", file)
+	logging.Logger.Info().Msgf("uploading asset %s", file)
 
 	f, err := os.Open(file)
 	if err != nil {
